@@ -67,6 +67,7 @@ sub init_human_text{
 	['festival',_('A Text to Speech synthesis software'),'festival'],
 	['fnfxd',_('Power and special key management for Toshiba laptops'),'fnfxd'],
 	['gdm',_('GNOME Display Manager'),'gdm'],
+	['hal',_('A layer for hardware support and detection'),'hald'],
 	['hdparm',_('Tunes hard disk parameters for high performance'),0],
 	['hotkey-setup',_('Auto-configures laptop hotkeys'),0],
 	['hotplug',_('Detects new devices when plugged in'),0],
@@ -77,6 +78,7 @@ sub init_human_text{
 	['inetd',_('Manager for incoming Internet connections'),'inetd'],
 	['kdm',_('KDE Display Manager'),'kdm'],
 	['klogd',_('Logs important system events'),'klogd'],
+	['landscape-client',_('Web-base tool for managing Ubuntu systems'),'landscape-client'],
 	['laptop-mode',_('Auto-enables laptop mode when running on batteries'),0],
 	['lvm',_('Handles physical Hard Disk Volumes in Logical groups'),0],
 	['makedev',_('Creates special files to interact with hardware'),0],
@@ -93,10 +95,13 @@ sub init_human_text{
 	['postfix',_('High performance Mail Server'),'master'],
 	['powernowd',_('Controls CPU speed and voltage to save power'),'powernowd'],
 	['ppp',_('Manages internet access via a modem'),'pppd'],
+	['policykit',_('Framework for managing administrative privileges'),0],
+	['pulseaudio',_('New generation audio server'),'pulseaudio'],
 	['readahead',_('Speeds up boot by starting operations early'),0],
 	['rsync',_('Fast remote file copy program'),'rsyncd'],
 	['samba',_('Share files among computers on a LAN'),'smbd'],
 	['sl-modem-daemon',_('SmartLink modem management'),'slmodemd'],
+	['smartmontools',_('Monitors hard drives with SMART'), 'smartd'],
 	['squid',_('Internet WWW proxy server'),'squid'],
 	['spamassassin',_('Mail spam filter'),'spamd'],
 	['ssh',_('Allows users securely to log into the machine remotely'),'sshd'],
@@ -108,6 +113,7 @@ sub init_human_text{
 	['udev-mtab',_('Creates new devices when plugged in'),'udevd'],
 	['usplash',_('User bootsplash utility'),0],
 	['vbesave',_('Save/Recover video state'),0],
+	['vmware-server',_('Virtual Machine Server'),'vmware-serverd'],
 	['vsftpd',_('The Very Secure FTP daemon'),'vsftpd'],
 	['webmin',_('Web-based remote administration for this computer'),'miniserv.pl'],
 	['wifi-radar',_('Graphical utility for managing wi-fi connections'),'wifi-radar'],
