@@ -25,11 +25,12 @@
 package  bum_ops ;
 
 use strict ;
-use Encode qw(decode encode);
+use Encode ;
 use vars qw($application);
 use Glib qw(TRUE FALSE);
 use Gtk2::SimpleList;
 
+
 ## summary treeview
 use constant {
 	SUM_TOGGLE		=>	0,
@@ -473,9 +474,9 @@ sub set_info_text
 	my ($pkg,$info) = bumlib::new_get_script_info($key);
 
 	$buffer->delete($buffer->get_start_iter,$buffer->get_end_iter);
-  	$buffer->insert($buffer->get_start_iter,$key.": ".$pkg."\n");
+  	$buffer->insert($buffer->get_start_iter,$key.": ".$pkg."\n\n");
 	$buffer->apply_tag_by_name ('title', $buffer->get_start_iter, $buffer->get_end_iter);
-  	$buffer->insert($buffer->get_end_iter,$info);
+  	$buffer->insert($buffer->get_end_iter,decode_utf8($info));
 	
 }
 
